ItemViewBuilder class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- ItemViewBuilder
Constructors
-
ItemViewBuilder({Key? key, int length = 0, String? emptyDataText, required Widget itemBuilder(BuildContext, int), required Future<
void> onRefresh(), ScrollController? scrollController, LoadingStatus loadingStatus = LoadingStatus.completed, LoadingStatus isMoreLoading = LoadingStatus.completed, Widget? loadingWidget, String? errorText, Widget? errorWidget, Widget? emptyWidget, EdgeInsetsGeometry? padding}) -
const
Properties
- emptyDataText → String?
-
final
- emptyWidget → Widget?
-
final
- errorText → String?
-
final
- errorWidget → Widget?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMoreLoading → LoadingStatus
-
final
- itemBuilder → Widget Function(BuildContext, int)
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- length → int
-
final
- loadingStatus → LoadingStatus
-
final
- loadingWidget → Widget?
-
final
-
onRefresh
→ Future<
void> Function() -
final
- padding → EdgeInsetsGeometry?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollController → ScrollController?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited